histomicstk.workflows
======================

.. automodule:: histomicstk.workflows
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 1

    Workflow runner <histomicstk.workflows.workflow_runner.rst>
    Specific workflows <histomicstk.workflows.specific_workflows.rst>
